@@ -44,9 +44,10 @@ logger = logging.getLogger(__name__)
 class FailureException(Exception):
     """Basic failure exception I can throw to force a retry."""
 
-    def __init__(self, code, message="Something went wrong"):
+    def __init__(self, code, message="Something went wrong", rescrape=False):
         self.code = code
         self.message = message
+        self.rescrape = rescrape
         super().__init__(self.message)
         super().__init__(self.code)
 
@@ -55,9 +56,10 @@ async def sanitize(name: str) -> str:
     return re.sub(r'[<>:"/\\|?*\']', "", name).strip()
 
 
-async def log(text, style=Fore.WHITE) -> None:
+async def log(text, style=Fore.WHITE, quiet=False) -> None:
     logger.debug(text)
-    print(style + str(text) + Style.RESET_ALL)
+    if not quiet:
+        print(style + str(text) + Style.RESET_ALL)
 
 
 async def clear() -> None:
@@ -85,6 +87,9 @@ async def purge_dir(dirname, in_place=True):
 
 
 async def regex_links(urls) -> list:
+    if urls.lstrip().startswith('#'):
+        return []
+
     all_links = [x.group().replace(".md.", ".") for x in re.finditer(
         r"(?:http.*?)(?=($|\n|\r\n|\r|\s|\"|\[/URL]|]\[|\[/img]))", urls)]
     yarl_links = []
@@ -109,10 +114,10 @@ async def write_last_post_file(file: Path, url: str):
 
 
 async def check_direct(url: URL):
-    mapping_direct = [r'i.pixl.is', r'i..pixl.is', r'img-...cyberdrop...', r'f.cyberdrop...',
+    mapping_direct = [r'i.pixl.li', r'i..pixl.li', r'img-...cyberdrop...', r'f.cyberdrop...',
                       r'fs-...cyberdrop...', r'i.bunkr...', r'i..bunkr...', r'i...bunkr...', r'media-files.bunkr...',
                       r'media-files..bunkr...', r'cdn.bunkr...', r'cdn..bunkr...', r'cdn...bunkr...',
-                      r'jpg.church/images/...', r'simp..jpg.church', r's..putmega.com', r's..putme.ga',]
+                      r'jpg.church/images/...', r'simp..jpg.church', r's..putmega.com', r's..putme.ga', r'images..imgbox.com' ]
     return any(re.search(domain, url.host) for domain in mapping_direct)
 
 
