@@ -33,6 +33,21 @@ class AlbumItem:
     async def set_new_title(self, new_title: str):
         self.title = new_title
 
+    async def get_referrer(self, link: URL):
+        for pair in self.link_pairs:
+            if link == pair[0]:
+                return pair[1]
+
+    async def replace_link_pairs(self, link_pairs_in):
+        map = {}
+        for link_pair in link_pairs_in:
+            for pair in self.link_pairs:
+                if link_pair[0].parts[-1] == pair[0].parts[-1]:
+                    self.link_pairs.remove(pair)
+                    self.link_pairs.append(link_pair)
+                    map[pair[0]] = link_pair[0]
+        return map
+
 
 @dataclass
 class DomainItem:
@@ -139,6 +154,6 @@ class AuthData:
 class SkipData:
     supported_hosts: ClassVar[Tuple[str]] = (
         "anonfiles", "bayfiles", "bunkr", "coomer.party", "cyberdrop", "cyberfile", "erome", "gfycat", "gofile",
-        "hgamecg", "img.kiwi", "jpg.church", "kemono.party", "pixeldrain", "pixl.is", "postimg.cc", "redgifs", "rule34",
-        "saint", "socialmediagirls", "simpcity", "xbunker", "xbunkr")
+        "hgamecg", "imgbox", "img.kiwi", "jpg.church", "kemono.party", "pixeldrain", "pixl.li", "postimg.cc",
+        "redgifs", "rule34", "saint", "socialmediagirls", "simpcity", "xbunker", "xbunkr")
     sites: List[str]
